==> kkbox_openapi-0.9.4.tar.gz: lib/src/types.dart <==
class PagingInfo {
  int limit = 0;
  int offset = 0;
  String url;
  String next;

  PagingInfo(Map<String, dynamic> jsonObject) {
    this.limit = jsonObject['limit'] ?? 0;
    this.offset = jsonObject['offset'] ?? 0;
    this.url = jsonObject['url'];
    this.next = jsonObject['next'];
  }
  toString() {
    return '''<PageInfo limit: ${this.limit} offset: ${this.offset} url: ${this.url} next: ${this.next}>''';
  }
}

class Summary {
  int total = 0;

  Summary(Map<String, dynamic> jsonObject) {
    this.total = jsonObject['total'];
  }
  toString() {
    return '''<Summary total: ${this.total}>''';
  }
}

/// Represents Metadata of an image.
class Image {
  /// Width of the image.
  int width = 0;

  /// Height of the image.
  int height = 0;

  /// URL of the image.
  String url;

  Image(Map<String, dynamic> jsonObject) {
    this.width = jsonObject['width'] ?? 0;
    this.height = jsonObject['height'] ?? 0;
    this.url = jsonObject['url'] ?? url;
  }

  toString() {
    return '''<Image url: ${this.url}, width: ${this.width}, height: ${this.height}>''';
  }
}

/// Represents an artist in KKBOX's Open API.
class ArtistInfo {
  /// ID of the artist.
  String id;

  /// Name of the artist.
  String name;

  /// URL of the page of the artist.
  String url;

  /// Profile image.
  List<Image> images;

  ArtistInfo(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.name = jsonObject['name'] ?? '';
    this.url = jsonObject['url'] ?? '';
    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
  }

  String toString() {
    return '''<ArtistInfo id: ${this.id},
    name: ${this.name},
    url: ${this.url},
    images: ${this.images}>''';
  }
}

/// Represents a list of artists.
class ArtistList {
  List<ArtistInfo> artists;
  PagingInfo paging;
  Summary summary;

  ArtistList(Map<String, dynamic> jsonObject) {
    this.artists = [];
    for (final artistObject in jsonObject['data']) {
      this.artists.add(new ArtistInfo(artistObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

/// Represents an album in KKBOX's Open API.
class AlbumInfo {
  /// ID of the album.
  String id;

  /// Name of the album.
  String name;

  /// URL of the webpage for the album.
  String url;

  /// Artist that the album belongs to.
  ArtistInfo artist;

  /// Album cover images.
  List<Image> images;

  /// When is the album released.
  String releaseDate;

  /// If the album explicit or not.
  bool explicitness;
  List<String> territoriesThatAvailableAt;

  AlbumInfo(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.name = jsonObject['name'] ?? '';
    this.url = jsonObject['url'] ?? '';
    if (jsonObject['artist'] != null) {
      this.artist = new ArtistInfo(jsonObject['artist']);
    }
    this.releaseDate = jsonObject['release_date'] ?? '';
    this.explicitness = jsonObject['explicitness'] ?? false;
    this.territoriesThatAvailableAt = jsonObject['available_territories'] ?? [];
    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
  }

  String toString() {
    return '''<AlbumInfo id: ${this.id},
    name: ${this.name},
    url: ${this.url},
    releaseDate: ${this.releaseDate},
    images: ${this.images},
    explicitness: ${this.explicitness},
    territories: ${this.territoriesThatAvailableAt},
    artist: ${this.artist}>''';
  }
}

/// Represents a list of albums.
class AlbumList {
  List<AlbumInfo> albums;
  PagingInfo paging;
  Summary summary;

  AlbumList(Map<String, dynamic> jsonObject) {
    this.albums = [];
    for (final albumObject in jsonObject['data']) {
      this.albums.add(new AlbumInfo(albumObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

/// Represents a track in KKBOX's Open API.
class TrackInfo {
  /// ID of the track.
  String id;

  /// Name of the track.
  String name;

  /// URL of the webpage of the track.
  String url;

  /// The album that contains the song track.
  AlbumInfo album;

  /// Length of the track.
  double duration;

  /// Track order in the album.
  int trackOrderInAlbum;

  /// If the track is explicit or not.
  bool explicitness;
  List<String> territoriesThatAvailableAt;

  TrackInfo(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.name = jsonObject['name'] ?? '';
    this.url = jsonObject['url'] ?? '';
    this.duration = jsonObject['duration'] ?? 0;
    this.trackOrderInAlbum = jsonObject['track_number'] ?? 0;
    this.explicitness = jsonObject['explicitness'] ?? false;
    this.territoriesThatAvailableAt = jsonObject['available_territories'] ?? [];
    if (jsonObject['album'] != null) {
      this.album = new AlbumInfo(jsonObject['album']);
    }
  }

  String toString() {
    return '''<TrackInfo id: ${this.id},
    name: ${this.name},
    url: ${this.url},
    duration: ${this.duration},
    track_number: ${this.trackOrderInAlbum},
    explicitness: ${this.explicitness},
    territories: ${this.territoriesThatAvailableAt},
    album: ${this.album}>''';
  }
}

/// Represents a list of tracks.
class TrackList {
  List<TrackInfo> tracks;
  PagingInfo paging;
  Summary summary;

  TrackList(Map<String, dynamic> jsonObject) {
    this.tracks = [];
    for (final trackObject in jsonObject['data']) {
      this.tracks.add(new TrackInfo(trackObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

/// Represents a playlist in KKBOX's Open API.
class PlaylistInfo {
  /// ID of the playlist.
  String id;

  /// Title of the playlist.
  String title;

  /// Description of the playlist.
  String description;

  /// URL of the webpage of the playlist.
  String url;

  /// Playlist cover images.
  List<Image> images;

  /// The user that curates the playlist.
  UserInfo owner;

  /// When was the playlist updated.
  String lastUpdateDate;

  /// Tracks in the playlists. Might be null.
  TrackList tracks;

  PlaylistInfo(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.title = jsonObject['title'] ?? '';
    this.description = jsonObject['description'] ?? '';
    this.url = jsonObject['url'] ?? '';
    this.owner = new UserInfo(jsonObject['owner'] ?? {});
    this.lastUpdateDate = jsonObject['updated_at'] ?? '';
    if (jsonObject['tracks'] != null) {
      this.tracks = new TrackList(jsonObject['tracks']);
    }
    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
  }

  String toString() {
    return '''<PlaylistInfo id: ${this.id},
    title: ${this.title},
    url: ${this.url},
    description: ${this.description},
    images: ${this.images},
    owner: ${this.owner},
    lastUpdateDate: ${this.lastUpdateDate},
    tracks: ${tracks}>''';
  }
}

/// Represents a list of playlists.
class PlaylistList {
  List<PlaylistInfo> playlists;
  PagingInfo paging;
  Summary summary;

  PlaylistList(Map<String, dynamic> jsonObject) {
    this.playlists = [];
    for (final playlistObject in jsonObject['data']) {
      this.playlists.add(new PlaylistInfo(playlistObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

/// Represents a featured playlist category in KKBOX's Open API.
class FeaturedPlaylistCategory {
  /// ID of the category.
  String id;

  /// Title of the category.
  String title;

  /// Images for the category.
  List<Image> images;

  /// Playlists under the category. It might be null.
  PlaylistList playlists;

  FeaturedPlaylistCategory(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'];
    this.title = jsonObject['title'];
    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
    if (jsonObject['playlists'] != null) {
      this.playlists = new PlaylistList(jsonObject['playlists']);
    }
  }

  String toString() {
    return '''<FeaturedPlaylistCategory id: ${this.id},
    title: ${this.title},
    images: ${this.images},
    playlists: ${playlists}>''';
  }
}

/// Represents a list of featured playlist category.
class FeaturedPlaylistCategoryList {
  List<FeaturedPlaylistCategory> categories;
  PagingInfo paging;
  Summary summary;

  FeaturedPlaylistCategoryList(Map<String, dynamic> jsonObject) {
    this.categories = [];
    for (final playlistObject in jsonObject['data']) {
      this.categories.add(new FeaturedPlaylistCategory(playlistObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

/// Represents a new released album category in KKBOX's Open API.
class NewReleasedAlbumsCategory {
  String id;
  String title;
  AlbumList albums;

  NewReleasedAlbumsCategory(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.title = jsonObject['title'] ?? '';
    if (jsonObject['albums'] != null) {
      this.albums = new AlbumList(jsonObject['albums']);
    }
  }

  String toString() {
    return '''<NewReleasedAlbumsCategory id: ${this.id},
    title: ${this.title},
    albums: ${albums}>''';
  }
}

/// Represents a list of new released album category.
class NewReleasedAlbumsCategoryList {
  List<NewReleasedAlbumsCategory> categories;
  PagingInfo paging;
  Summary summary;

  NewReleasedAlbumsCategoryList(Map<String, dynamic> jsonObject) {
    this.categories = [];
    for (final categortObject in jsonObject['data']) {
      this.categories.add(new NewReleasedAlbumsCategory(categortObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

/// Represents a radio station on KKBOX, including mood stations and genre stations.
class RadioStation {
  /// ID of the radio station.
  String id;

  /// Name of the radio station.
  String name;

  /// Category of the radio station. Only applied on genre stations.
  String category;

  /// Images of the radio station. Only applied on mood stations.
  List<Image> images;

  /// Tracks in the station.
  TrackList tracks;

  RadioStation(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.name = jsonObject['name'] ?? '';
    this.category = jsonObject['category'];
    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
    if (jsonObject['tracks'] != null) {
      this.tracks = new TrackList(jsonObject['tracks']);
    }
  }

  String toString() {
    return '''<RadioStation id: ${this.id},
    name: ${this.name},
    category: ${this.category},
    images: ${this.images},
    tracks: ${this.tracks}>''';
  }
}

/// Represents A list of radio stations.
class RadioStationList {
  List<RadioStation> stations;
  PagingInfo paging;
  Summary summary;

  RadioStationList(Map<String, dynamic> jsonObject) {
    this.stations = [];
    for (final stationObject in jsonObject['data']) {
      this.stations.add(new RadioStation(stationObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

/// Represents a user in KKBOX.
class UserInfo {
  String id;
  String name;
  String url;
  String description;
  List<Image> images;

  UserInfo(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.name = jsonObject['name'] ?? '';
    this.url = jsonObject['url'] ?? '';
    this.description = jsonObject['description'] ?? '';

    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
  }
}

/// Represents search results.
class SearchResults {
  /// Track search results.
  TrackList trackResults;

  /// Album search results.
  AlbumList albumResults;

  /// Artist search results.
  ArtistList artistResults;

  /// Playlist search results.
  PlaylistList playlistResults;
  PagingInfo paging;
  Summary summary;

  SearchResults(Map<String, dynamic> jsonObject) {
    if (jsonObject['tracks'] != null) {
      this.trackResults = new TrackList(jsonObject['tracks']);
    }
    if (jsonObject['albums'] != null) {
      this.albumResults = new AlbumList(jsonObject['albums']);
    }
    if (jsonObject['artists'] != null) {
      this.artistResults = new ArtistList(jsonObject['artists']);
    }
    if (jsonObject['playlists'] != null) {
      this.playlistResults = new PlaylistList(jsonObject['playlists']);
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

==> kkbox_openapi-0.9.5.tar.gz: lib/src/types.dart <==
class PagingInfo {
  int limit = 0;
  int offset = 0;
  String url;
  String next;

  PagingInfo(Map<String, dynamic> jsonObject) {
    this.limit = jsonObject['limit'] ?? 0;
    this.offset = jsonObject['offset'] ?? 0;
    this.url = jsonObject['url'];
    this.next = jsonObject['next'];
  }

  toString() {
    return '''<PageInfo limit: ${this.limit} offset: ${this.offset} url: ${this
        .url} next: ${this.next}>''';
  }
}

class Summary {
  int total = 0;

  Summary(Map<String, dynamic> jsonObject) {
    this.total = jsonObject['total'];
  }

  toString() {
    return '''<Summary total: ${this.total}>''';
  }
}

// Metadata of an image.
class Image {
  /// Width of the image.
  int width = 0;

  /// Height of the image.
  int height = 0;

  /// URL of the image.
  String url;

  Image(Map<String, dynamic> jsonObject) {
    this.width = jsonObject['width'] ?? 0;
    this.height = jsonObject['height'] ?? 0;
    this.url = jsonObject['url'] ?? url;
  }

  toString() {
    return '''<Image url: ${this.url}, width: ${this.width}, height: ${this
        .height}>''';
  }
}

/// An object that represents an artist in KKBOX's Open API.
class ArtistInfo {
  /// ID of the artist.
  String id;

  /// Name of the artist.
  String name;

  /// URL of the page of the artist.
  String url;

  /// Profile image.
  List<Image> images;

  ArtistInfo(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.name = jsonObject['name'] ?? '';
    this.url = jsonObject['url'] ?? '';
    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
  }

  String toString() {
    return '''<ArtistInfo id: ${this.id},
    name: ${this.name},
    url: ${this.url},
    images: ${this.images}>''';
  }
}

class ArtistList {
  List<ArtistInfo> artists;
  PagingInfo paging;
  Summary summary;

  ArtistList(Map<String, dynamic> jsonObject) {
    this.artists = [];
    for (final artistObject in jsonObject['data']) {
      this.artists.add(new ArtistInfo(artistObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

class AlbumInfo {
  /// ID of the album.
  String id;

  /// Name of the album.
  String name;

  /// URL of the webpage for the album.
  String url;

  /// Artist that the album belongs to.
  ArtistInfo artist;

  /// Album cover images.
  List<Image> images;

  /// When is the album released.
  String releaseDate;

  /// If the album explicit or not.
  bool explicitness;
  List<String> territoriesThatAvailableAt;

  AlbumInfo(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.name = jsonObject['name'] ?? '';
    this.url = jsonObject['url'] ?? '';
    if (jsonObject['artist'] != null) {
      this.artist = new ArtistInfo(jsonObject['artist']);
    }
    this.releaseDate = jsonObject['release_date'] ?? '';
    this.explicitness = jsonObject['explicitness'] ?? false;
    List<dynamic> terr = (jsonObject['available_territories'] ?? []);
    this.territoriesThatAvailableAt = terr.map<String>((x) => x).toList();
    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
  }

  String toString() {
    return '''<AlbumInfo id: ${this.id},
    name: ${this.name},
    url: ${this.url},
    releaseDate: ${this.releaseDate},
    images: ${this.images},
    explicitness: ${this.explicitness},
    territories: ${this.territoriesThatAvailableAt},
    artist: ${this.artist}>''';
  }
}

class AlbumList {
  List<AlbumInfo> albums;
  PagingInfo paging;
  Summary summary;

  AlbumList(Map<String, dynamic> jsonObject) {
    this.albums = [];
    for (final albumObject in jsonObject['data']) {
      this.albums.add(new AlbumInfo(albumObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

class TrackInfo {
  /// ID of the track.
  String id;

  /// Name of the track.
  String name;

  /// URL of the webpage of the track.
  String url;

  /// The album that contains the song track.
  AlbumInfo album;

  /// Length of the track.
  int duration;

  /// Track order in the album.
  int trackOrderInAlbum;

  /// If the track is explicit or not.
  bool explicitness;
  List<String> territoriesThatAvailableAt;

  TrackInfo(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.name = jsonObject['name'] ?? '';
    this.url = jsonObject['url'] ?? '';
    this.duration = jsonObject['duration'] ?? 0;
    this.trackOrderInAlbum = jsonObject['track_number'] ?? 0;
    this.explicitness = jsonObject['explicitness'] ?? false;
    List<dynamic> terr = (jsonObject['available_territories'] ?? []);
    this.territoriesThatAvailableAt = terr.map<String>((x) => x).toList();
    if (jsonObject['album'] != null) {
      this.album = new AlbumInfo(jsonObject['album']);
    }
  }

  String toString() {
    return '''<TrackInfo id: ${this.id},
    name: ${this.name},
    url: ${this.url},
    duration: ${this.duration},
    track_number: ${this.trackOrderInAlbum},
    explicitness: ${this.explicitness},
    territories: ${this.territoriesThatAvailableAt},
    album: ${this.album}>''';
  }
}

class TrackList {
  List<TrackInfo> tracks;
  PagingInfo paging;
  Summary summary;

  TrackList(Map<String, dynamic> jsonObject) {
    this.tracks = [];
    for (final trackObject in jsonObject['data']) {
      this.tracks.add(new TrackInfo(trackObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

class PlaylistInfo {
  /// ID of the playlist.
  String id;

  /// Title of the playlist.
  String title;

  /// Description of the playlist.
  String description;

  /// URL of the webpage of the playlist.
  String url;

  /// Playlist cover images.
  List<Image> images;

  /// The user that curates the playlist.
  UserInfo owner;

  /// When was the playlist updated.
  String lastUpdateDate;

  /// Tracks in the playlists. Might be null.
  TrackList tracks;

  Map<String, dynamic> apiJsonObject;

  PlaylistInfo(Map<String, dynamic> jsonObject) {
    this.apiJsonObject = jsonObject;
    this.id = jsonObject['id'] ?? '';
    this.title = jsonObject['title'] ?? '';
    this.description = jsonObject['description'] ?? '';
    this.url = jsonObject['url'] ?? '';
    this.owner = new UserInfo(jsonObject['owner'] ?? {});
    this.lastUpdateDate = jsonObject['updated_at'] ?? '';
    if (jsonObject['tracks'] != null) {
      this.tracks = new TrackList(jsonObject['tracks']);
    }
    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
  }

  String toString() {
    return '''<PlaylistInfo id: ${this.id},
    title: ${this.title},
    url: ${this.url},
    description: ${this.description},
    images: ${this.images},
    owner: ${this.owner},
    lastUpdateDate: ${this.lastUpdateDate},
    tracks: ${tracks}>''';
  }
}

class PlaylistList {
  List<PlaylistInfo> playlists;
  PagingInfo paging;
  Summary summary;

  PlaylistList(Map<String, dynamic> jsonObject) {
    this.playlists = [];
    for (final playlistObject in jsonObject['data']) {
      this.playlists.add(new PlaylistInfo(playlistObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

class FeaturedPlaylistCategory {
  /// ID of the category.
  String id;

  /// Title of the category.
  String title;

  /// Images for the category.
  List<Image> images;

  /// Playlists under the category. It might be null.
  PlaylistList playlists;

  FeaturedPlaylistCategory(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'];
    this.title = jsonObject['title'];
    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
    if (jsonObject['playlists'] != null) {
      this.playlists = new PlaylistList(jsonObject['playlists']);
    }
  }

  String toString() {
    return '''<FeaturedPlaylistCategory id: ${this.id},
    title: ${this.title},
    images: ${this.images},
    playlists: ${playlists}>''';
  }
}

class FeaturedPlaylistCategoryList {
  List<FeaturedPlaylistCategory> categories;
  PagingInfo paging;
  Summary summary;

  FeaturedPlaylistCategoryList(Map<String, dynamic> jsonObject) {
    this.categories = [];
    for (final playlistObject in jsonObject['data']) {
      this.categories.add(new FeaturedPlaylistCategory(playlistObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

class NewReleasedAlbumsCategory {
  String id;
  String title;
  AlbumList albums;

  NewReleasedAlbumsCategory(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.title = jsonObject['title'] ?? '';
    if (jsonObject['albums'] != null) {
      this.albums = new AlbumList(jsonObject['albums']);
    }
  }

  String toString() {
    return '''<NewReleasedAlbumsCategory id: ${this.id},
    title: ${this.title},
    albums: ${albums}>''';
  }
}

class NewReleasedAlbumsCategoryList {
  List<NewReleasedAlbumsCategory> categories;
  PagingInfo paging;
  Summary summary;

  NewReleasedAlbumsCategoryList(Map<String, dynamic> jsonObject) {
    this.categories = [];
    for (final categortObject in jsonObject['data']) {
      this.categories.add(new NewReleasedAlbumsCategory(categortObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

/// The class represents radio stations on KKBOX, including mood stations and genre stations.
class RadioStation {
  /// ID of the radio station.
  String id;

  /// Name of the radio station.
  String name;

  /// Category of the radio station. Only applied on genre stations.
  String category;

  /// Images of the radio station. Only applied on mood stations.
  List<Image> images;

  /// Tracks in the station.
  TrackList tracks;

  RadioStation(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.name = jsonObject['name'] ?? '';
    this.category = jsonObject['category'];
    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
    if (jsonObject['tracks'] != null) {
      this.tracks = new TrackList(jsonObject['tracks']);
    }
  }

  String toString() {
    return '''<RadioStation id: ${this.id},
    name: ${this.name},
    category: ${this.category},
    images: ${this.images},
    tracks: ${this.tracks}>''';
  }
}

class RadioStationList {
  List<RadioStation> stations;
  PagingInfo paging;
  Summary summary;

  RadioStationList(Map<String, dynamic> jsonObject) {
    this.stations = [];
    for (final stationObject in jsonObject['data']) {
      this.stations.add(new RadioStation(stationObject));
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}

class UserInfo {
  String id;
  String name;
  String url;
  String description;
  List<Image> images;

  UserInfo(Map<String, dynamic> jsonObject) {
    this.id = jsonObject['id'] ?? '';
    this.name = jsonObject['name'] ?? '';
    this.url = jsonObject['url'] ?? '';
    this.description = jsonObject['description'] ?? '';

    this.images = [];
    for (var imageObject in (jsonObject['images'] ?? [])) {
      this.images.add(new Image(imageObject));
    }
  }
}

class SearchResults {
  TrackList trackResults;
  AlbumList albumResults;
  ArtistList artistResults;
  PlaylistList playlistResults;
  PagingInfo paging;
  Summary summary;

  SearchResults(Map<String, dynamic> jsonObject) {
    if (jsonObject['tracks'] != null) {
      this.trackResults = new TrackList(jsonObject['tracks']);
    }
    if (jsonObject['albums'] != null) {
      this.albumResults = new AlbumList(jsonObject['albums']);
    }
    if (jsonObject['artists'] != null) {
      this.artistResults = new ArtistList(jsonObject['artists']);
    }
    if (jsonObject['playlists'] != null) {
      this.playlistResults = new PlaylistList(jsonObject['playlists']);
    }
    this.paging = new PagingInfo(jsonObject['paging']);
    this.summary = new Summary(jsonObject['summary']);
  }
}
